CVS commit: [pgoyette-compat] src

2018-03-27 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Wed Mar 28 04:18:25 UTC 2018

Modified Files:
src/distrib/sets/lists/modules [pgoyette-compat]: mi
src/sys/compat/common [pgoyette-compat]: Makefile.sysio compat_mod.c
compat_mod.h files.common kern_time_30.c uipc_syscalls_30.c
vfs_syscalls_30.c
src/sys/dev [pgoyette-compat]: bio.c
src/sys/kern [pgoyette-compat]: compat_stub.c
src/sys/modules [pgoyette-compat]: Makefile
src/sys/sys [pgoyette-compat]: compat_stub.h
Added Files:
src/sys/compat/common [pgoyette-compat]: bio_30.c compat_30_mod.c
src/sys/modules/compat_30 [pgoyette-compat]: Makefile

Log Message:
Initial pass at a compat_30 module.

Still needs some work for dev/vnd and various dev/usb/*


To generate a diff of this commit:
cvs rdiff -u -r1.114.2.7 -r1.114.2.8 src/distrib/sets/lists/modules/mi
cvs rdiff -u -r1.7.18.16 -r1.7.18.17 src/sys/compat/common/Makefile.sysio
cvs rdiff -u -r0 -r1.1.2.1 src/sys/compat/common/bio_30.c \
src/sys/compat/common/compat_30_mod.c
cvs rdiff -u -r1.24.14.21 -r1.24.14.22 src/sys/compat/common/compat_mod.c
cvs rdiff -u -r1.1.42.9 -r1.1.42.10 src/sys/compat/common/compat_mod.h
cvs rdiff -u -r1.1.2.19 -r1.1.2.20 src/sys/compat/common/files.common
cvs rdiff -u -r1.5 -r1.5.14.1 src/sys/compat/common/kern_time_30.c
cvs rdiff -u -r1.3 -r1.3.96.1 src/sys/compat/common/uipc_syscalls_30.c
cvs rdiff -u -r1.36 -r1.36.18.1 src/sys/compat/common/vfs_syscalls_30.c
cvs rdiff -u -r1.13 -r1.13.16.1 src/sys/dev/bio.c
cvs rdiff -u -r1.1.2.8 -r1.1.2.9 src/sys/kern/compat_stub.c
cvs rdiff -u -r1.202.2.11 -r1.202.2.12 src/sys/modules/Makefile
cvs rdiff -u -r0 -r1.1.2.1 src/sys/modules/compat_30/Makefile
cvs rdiff -u -r1.1.2.8 -r1.1.2.9 src/sys/sys/compat_stub.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/modules/mi
diff -u src/distrib/sets/lists/modules/mi:1.114.2.7 src/distrib/sets/lists/modules/mi:1.114.2.8
--- src/distrib/sets/lists/modules/mi:1.114.2.7	Tue Mar 27 07:29:43 2018
+++ src/distrib/sets/lists/modules/mi	Wed Mar 28 04:18:24 2018
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.114.2.7 2018/03/27 07:29:43 pgoyette Exp $
+# $NetBSD: mi,v 1.114.2.8 2018/03/28 04:18:24 pgoyette Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 #
@@ -68,6 +68,8 @@
 ./@MODULEDIR@/coda5/coda5.kmod			base-kernel-modules	kmod
 ./@MODULEDIR@/compatbase-kernel-modules	kmod
 ./@MODULEDIR@/compat/compat.kmod		base-kernel-modules	kmod
+./@MODULEDIR@/compat_30base-kernel-modules	kmod
+./@MODULEDIR@/compat_30/compat_30.kmod		base-kernel-modules	kmod
 ./@MODULEDIR@/compat_40base-kernel-modules	kmod
 ./@MODULEDIR@/compat_40/compat_40.kmod		base-kernel-modules	kmod
 ./@MODULEDIR@/compat_50base-kernel-modules	kmod

Index: src/sys/compat/common/Makefile.sysio
diff -u src/sys/compat/common/Makefile.sysio:1.7.18.16 src/sys/compat/common/Makefile.sysio:1.7.18.17
--- src/sys/compat/common/Makefile.sysio:1.7.18.16	Sun Mar 25 21:27:51 2018
+++ src/sys/compat/common/Makefile.sysio	Wed Mar 28 04:18:24 2018
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.sysio,v 1.7.18.16 2018/03/25 21:27:51 pgoyette Exp $
+#	$NetBSD: Makefile.sysio,v 1.7.18.17 2018/03/28 04:18:24 pgoyette Exp $
 
 # Sources for syscall and ioctl compatibility across the versions.
 
@@ -28,7 +28,7 @@ SRCS+=	rtsock_14.c
 SRCS+=	vfs_syscalls_20.c
 
 # Compatibility code for NetBSD 3.0
-SRCS+=	kern_time_30.c vfs_syscalls_30.c uipc_syscalls_30.c
+SRCS+=	kern_time_30.c vfs_syscalls_30.c uipc_syscalls_30.c bio_30.c
 
 # Compatibility code for NetBSD 4.0
 SRCS+=	vfs_syscalls_40.c uipc_syscalls_40.c

Index: src/sys/compat/common/compat_mod.c
diff -u src/sys/compat/common/compat_mod.c:1.24.14.21 src/sys/compat/common/compat_mod.c:1.24.14.22
--- src/sys/compat/common/compat_mod.c:1.24.14.21	Tue Mar 27 07:29:43 2018
+++ src/sys/compat/common/compat_mod.c	Wed Mar 28 04:18:24 2018
@@ -1,4 +1,4 @@
-/*	$NetBSD: compat_mod.c,v 1.24.14.21 2018/03/27 07:29:43 pgoyette Exp $	*/
+/*	$NetBSD: compat_mod.c,v 1.24.14.22 2018/03/28 04:18:24 pgoyette Exp $	*/
 
 /*-
  * Copyright (c) 2008 The NetBSD Foundation, Inc.
@@ -34,7 +34,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: compat_mod.c,v 1.24.14.21 2018/03/27 07:29:43 pgoyette Exp $");
+__KERNEL_RCSID(0, "$NetBSD: compat_mod.c,v 1.24.14.22 2018/03/28 04:18:24 pgoyette Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_compat_netbsd.h"
@@ -172,19 +172,6 @@ static const struct syscall_package comp
 	{ SYS_compat_20_getfsstat, 0, (sy_call_t *)compat_20_sys_getfsstat },
 	{ SYS_compat_20_statfs, 0, (sy_call_t *)compat_20_sys_statfs },
 #endif
-
-#if defined(COMPAT_30)
-	{ SYS_compat_30___fhstat30, 0, (sy_call_t *)compat_30_sys___fhstat30 },
-	{ SYS_compat_30___fstat13, 0, (sy_call_t *)compat_30_sys___fstat13 },
-	{ SYS_compat_30___lstat13, 0, (sy_call_t *)compat_30_sys___lstat13 },
-	{ 

CVS commit: [pgoyette-compat] src/doc

2018-03-27 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Wed Mar 28 03:41:26 UTC 2018

Modified Files:
src/doc [pgoyette-compat]: COMPAT-branch-notes

Log Message:
Add some reminders


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.7 -r1.1.2.8 src/doc/COMPAT-branch-notes

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/COMPAT-branch-notes
diff -u src/doc/COMPAT-branch-notes:1.1.2.7 src/doc/COMPAT-branch-notes:1.1.2.8
--- src/doc/COMPAT-branch-notes:1.1.2.7	Sun Mar 25 23:53:51 2018
+++ src/doc/COMPAT-branch-notes	Wed Mar 28 03:41:26 2018
@@ -43,7 +43,10 @@ TODO
Update:  These are being done simultaneously, with compat code being
moved directly to a version-specific module.  All of COMPAT_80 and
COMPAT_70, most of COMPAT_60, and much of COMPAT_50 are finished.
-   Need to decide how to handle the COMPAT_BSDPTY stuff.
+   Still need to decide how to handle the COMPAT_BSDPTY stuff.
+
+   COMPAT_40 is also finished, except for some arch/sh3 MD code.  There
+   is also some arch/m68k MD-specific code remaining for COMPAT_50.
 
 3. XXX The compat_60 module still needs some work for XEN systems.
 



CVS commit: [pgoyette-compat] src/sys/net80211

2018-03-27 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Wed Mar 28 00:30:05 UTC 2018

Modified Files:
src/sys/net80211 [pgoyette-compat]: ieee80211_ioctl.c

Log Message:
No need to make the #include conditional;  the included file contains
all required conditions.


To generate a diff of this commit:
cvs rdiff -u -r1.60 -r1.60.16.1 src/sys/net80211/ieee80211_ioctl.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/net80211/ieee80211_ioctl.c
diff -u src/sys/net80211/ieee80211_ioctl.c:1.60 src/sys/net80211/ieee80211_ioctl.c:1.60.16.1
--- src/sys/net80211/ieee80211_ioctl.c:1.60	Mon Aug 24 22:21:26 2015
+++ src/sys/net80211/ieee80211_ioctl.c	Wed Mar 28 00:30:05 2018
@@ -1,4 +1,4 @@
-/*	$NetBSD: ieee80211_ioctl.c,v 1.60 2015/08/24 22:21:26 pooka Exp $	*/
+/*	$NetBSD: ieee80211_ioctl.c,v 1.60.16.1 2018/03/28 00:30:05 pgoyette Exp $	*/
 /*-
  * Copyright (c) 2001 Atsushi Onoe
  * Copyright (c) 2002-2005 Sam Leffler, Errno Consulting
@@ -36,7 +36,7 @@
 __FBSDID("$FreeBSD: src/sys/net80211/ieee80211_ioctl.c,v 1.35 2005/08/30 14:27:47 avatar Exp $");
 #endif
 #ifdef __NetBSD__
-__KERNEL_RCSID(0, "$NetBSD: ieee80211_ioctl.c,v 1.60 2015/08/24 22:21:26 pooka Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ieee80211_ioctl.c,v 1.60.16.1 2018/03/28 00:30:05 pgoyette Exp $");
 #endif
 
 /*
@@ -72,12 +72,7 @@ __KERNEL_RCSID(0, "$NetBSD: ieee80211_io
 
 #include 
 
-#if defined(COMPAT_09) || defined(COMPAT_10) || defined(COMPAT_11) || \
-defined(COMPAT_12) || defined(COMPAT_13) || defined(COMPAT_14) || \
-defined(COMPAT_15) || defined(COMPAT_16) || defined(COMPAT_20) || \
-defined(COMPAT_30) || defined(COMPAT_40)
 #include 
-#endif
 
 #ifdef __FreeBSD__
 #define	IS_UP(_ic) \



CVS commit: src/external/gpl3/binutils/dist/bfd

2018-03-27 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Tue Mar 27 23:39:23 UTC 2018

Modified Files:
src/external/gpl3/binutils/dist/bfd: elflink.c

Log Message:
When trying to decide the status of a weak symbol, resolve any
indirectness first. In the case of various Qt5 libraries, __bss_start
ends up with a Qt5 version, but it has to be resolved first to match the
actual (implicit) definition. This fixes the root cause of pkg/53089.


To generate a diff of this commit:
cvs rdiff -u -r1.13 -r1.14 src/external/gpl3/binutils/dist/bfd/elflink.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/binutils/dist/bfd/elflink.c
diff -u src/external/gpl3/binutils/dist/bfd/elflink.c:1.13 src/external/gpl3/binutils/dist/bfd/elflink.c:1.14
--- src/external/gpl3/binutils/dist/bfd/elflink.c:1.13	Wed Oct 26 18:42:52 2016
+++ src/external/gpl3/binutils/dist/bfd/elflink.c	Tue Mar 27 23:39:23 2018
@@ -2675,14 +2675,17 @@ _bfd_elf_fix_symbol_flags (struct elf_li
  over to the real definition.  */
   if (h->u.weakdef != NULL)
 {
+  struct elf_link_hash_entry *weakdef = h->u.weakdef;
+  while (weakdef->root.type == bfd_link_hash_indirect)
+weakdef = (struct elf_link_hash_entry *) weakdef->root.u.i.link;
+
   /* If the real definition is defined by a regular object file,
 	 don't do anything special.  See the longer description in
 	 _bfd_elf_adjust_dynamic_symbol, below.  */
-  if (h->u.weakdef->def_regular)
+  if (weakdef->def_regular)
 	h->u.weakdef = NULL;
   else
 	{
-	  struct elf_link_hash_entry *weakdef = h->u.weakdef;
 
 	  while (h->root.type == bfd_link_hash_indirect)
 	h = (struct elf_link_hash_entry *) h->root.u.i.link;



CVS commit: src/external/bsd/pkg_install/dist

2018-03-27 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Tue Mar 27 23:11:26 UTC 2018

Removed Files:
src/external/bsd/pkg_install/dist: Makefile.in README config.guess
config.sub configure configure.ac install-sh tkpkg
src/external/bsd/pkg_install/dist/add: Makefile.in pkg_add.cat
src/external/bsd/pkg_install/dist/admin: Makefile.in audit-packages.cat
download-vulnerability-list.cat pkg_admin.cat
src/external/bsd/pkg_install/dist/create: Makefile.in pkg_create.cat
src/external/bsd/pkg_install/dist/delete: Makefile.in pkg_delete.cat
src/external/bsd/pkg_install/dist/info: Makefile.in pkg_info.cat
src/external/bsd/pkg_install/dist/lib: Makefile.in
pkg_install.conf.cat.in pkg_summary.cat pkgsrc.cat

Log Message:
Mark all files dead that should never have been imported.


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.1 -r0 src/external/bsd/pkg_install/dist/Makefile.in \
src/external/bsd/pkg_install/dist/README \
src/external/bsd/pkg_install/dist/config.guess \
src/external/bsd/pkg_install/dist/config.sub \
src/external/bsd/pkg_install/dist/configure \
src/external/bsd/pkg_install/dist/configure.ac \
src/external/bsd/pkg_install/dist/install-sh \
src/external/bsd/pkg_install/dist/tkpkg
cvs rdiff -u -r1.1.1.1 -r0 src/external/bsd/pkg_install/dist/add/Makefile.in
cvs rdiff -u -r1.2 -r0 src/external/bsd/pkg_install/dist/add/pkg_add.cat
cvs rdiff -u -r1.1.1.1 -r0 \
src/external/bsd/pkg_install/dist/admin/Makefile.in \
src/external/bsd/pkg_install/dist/admin/audit-packages.cat \
src/external/bsd/pkg_install/dist/admin/download-vulnerability-list.cat
cvs rdiff -u -r1.3 -r0 src/external/bsd/pkg_install/dist/admin/pkg_admin.cat
cvs rdiff -u -r1.1.1.1 -r0 \
src/external/bsd/pkg_install/dist/create/Makefile.in
cvs rdiff -u -r1.2 -r0 \
src/external/bsd/pkg_install/dist/create/pkg_create.cat
cvs rdiff -u -r1.1.1.1 -r0 \
src/external/bsd/pkg_install/dist/delete/Makefile.in
cvs rdiff -u -r1.2 -r0 \
src/external/bsd/pkg_install/dist/delete/pkg_delete.cat
cvs rdiff -u -r1.1.1.1 -r0 src/external/bsd/pkg_install/dist/info/Makefile.in
cvs rdiff -u -r1.2 -r0 src/external/bsd/pkg_install/dist/info/pkg_info.cat
cvs rdiff -u -r1.1.1.1 -r0 src/external/bsd/pkg_install/dist/lib/Makefile.in
cvs rdiff -u -r1.2 -r0 \
src/external/bsd/pkg_install/dist/lib/pkg_install.conf.cat.in \
src/external/bsd/pkg_install/dist/lib/pkg_summary.cat \
src/external/bsd/pkg_install/dist/lib/pkgsrc.cat

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [pgoyette-compat] src/sys

2018-03-27 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Tue Mar 27 23:11:18 UTC 2018

Modified Files:
src/sys/kern [pgoyette-compat]: init_sysent.c syscalls.c
syscalls_autoload.c systrace_args.c
src/sys/rump/include/rump [pgoyette-compat]: rump_syscalls.h
src/sys/rump/librump/rumpkern [pgoyette-compat]: rump_syscalls.c
src/sys/sys [pgoyette-compat]: syscall.h syscallargs.h

Log Message:
Regen


To generate a diff of this commit:
cvs rdiff -u -r1.319.2.5 -r1.319.2.6 src/sys/kern/init_sysent.c
cvs rdiff -u -r1.310.2.5 -r1.310.2.6 src/sys/kern/syscalls.c
cvs rdiff -u -r1.27.2.5 -r1.27.2.6 src/sys/kern/syscalls_autoload.c
cvs rdiff -u -r1.29.2.5 -r1.29.2.6 src/sys/kern/systrace_args.c
cvs rdiff -u -r1.108.2.5 -r1.108.2.6 \
src/sys/rump/include/rump/rump_syscalls.h
cvs rdiff -u -r1.137.2.5 -r1.137.2.6 \
src/sys/rump/librump/rumpkern/rump_syscalls.c
cvs rdiff -u -r1.304.2.5 -r1.304.2.6 src/sys/sys/syscall.h
cvs rdiff -u -r1.288.2.5 -r1.288.2.6 src/sys/sys/syscallargs.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/init_sysent.c
diff -u src/sys/kern/init_sysent.c:1.319.2.5 src/sys/kern/init_sysent.c:1.319.2.6
--- src/sys/kern/init_sysent.c:1.319.2.5	Sun Mar 25 07:19:47 2018
+++ src/sys/kern/init_sysent.c	Tue Mar 27 23:11:18 2018
@@ -1,14 +1,14 @@
-/* $NetBSD: init_sysent.c,v 1.319.2.5 2018/03/25 07:19:47 pgoyette Exp $ */
+/* $NetBSD: init_sysent.c,v 1.319.2.6 2018/03/27 23:11:18 pgoyette Exp $ */
 
 /*
  * System call switch table.
  *
  * DO NOT EDIT-- this file is automatically generated.
- * created from	NetBSD: syscalls.master,v 1.291.2.5 2018/03/25 07:19:13 pgoyette Exp
+ * created from	NetBSD: syscalls.master,v 1.291.2.6 2018/03/27 23:08:44 pgoyette Exp
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: init_sysent.c,v 1.319.2.5 2018/03/25 07:19:47 pgoyette Exp $");
+__KERNEL_RCSID(0, "$NetBSD: init_sysent.c,v 1.319.2.6 2018/03/27 23:11:18 pgoyette Exp $");
 
 #include "opt_modular.h"
 #include "opt_ntp.h"
@@ -897,7 +897,7 @@ struct sysent sysent[] = {
 	{
 		ns(struct compat_30_sys_ntp_gettime_args),
 		.sy_flags = SYCALL_ARG_PTR,
-		.sy_call = (sy_call_t *)compat_30(sys_ntp_gettime)
+		.sy_call = (sy_call_t *)sys_nomodule
 	},		/* 175 = compat_30_ntp_gettime */
 #if defined(NTP) || !defined(_KERNEL_OPT)
 	{

Index: src/sys/kern/syscalls.c
diff -u src/sys/kern/syscalls.c:1.310.2.5 src/sys/kern/syscalls.c:1.310.2.6
--- src/sys/kern/syscalls.c:1.310.2.5	Sun Mar 25 08:46:14 2018
+++ src/sys/kern/syscalls.c	Tue Mar 27 23:11:18 2018
@@ -1,14 +1,14 @@
-/* $NetBSD: syscalls.c,v 1.310.2.5 2018/03/25 08:46:14 pgoyette Exp $ */
+/* $NetBSD: syscalls.c,v 1.310.2.6 2018/03/27 23:11:18 pgoyette Exp $ */
 
 /*
  * System call names.
  *
  * DO NOT EDIT-- this file is automatically generated.
- * created from	NetBSD: syscalls.master,v 1.291.2.5 2018/03/25 07:19:13 pgoyette Exp
+ * created from	NetBSD: syscalls.master,v 1.291.2.6 2018/03/27 23:08:44 pgoyette Exp
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: syscalls.c,v 1.310.2.5 2018/03/25 08:46:14 pgoyette Exp $");
+__KERNEL_RCSID(0, "$NetBSD: syscalls.c,v 1.310.2.6 2018/03/27 23:11:18 pgoyette Exp $");
 
 #if defined(_KERNEL_OPT)
 #include "opt_modular.h"

Index: src/sys/kern/syscalls_autoload.c
diff -u src/sys/kern/syscalls_autoload.c:1.27.2.5 src/sys/kern/syscalls_autoload.c:1.27.2.6
--- src/sys/kern/syscalls_autoload.c:1.27.2.5	Sun Mar 25 07:19:47 2018
+++ src/sys/kern/syscalls_autoload.c	Tue Mar 27 23:11:18 2018
@@ -1,14 +1,14 @@
-/* $NetBSD: syscalls_autoload.c,v 1.27.2.5 2018/03/25 07:19:47 pgoyette Exp $ */
+/* $NetBSD: syscalls_autoload.c,v 1.27.2.6 2018/03/27 23:11:18 pgoyette Exp $ */
 
 /*
  * System call autoload table.
  *
  * DO NOT EDIT-- this file is automatically generated.
- * created from	NetBSD: syscalls.master,v 1.291.2.5 2018/03/25 07:19:13 pgoyette Exp
+ * created from	NetBSD: syscalls.master,v 1.291.2.6 2018/03/27 23:08:44 pgoyette Exp
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: syscalls_autoload.c,v 1.27.2.5 2018/03/25 07:19:47 pgoyette Exp $");
+__KERNEL_RCSID(0, "$NetBSD: syscalls_autoload.c,v 1.27.2.6 2018/03/27 23:11:18 pgoyette Exp $");
 
 #include 
 static struct sc_autoload netbsd_syscalls_autoload[] = {
@@ -88,6 +88,7 @@ static struct sc_autoload netbsd_syscall
 	{ SYS_compat_10_oshmsys, "compat_sysv" },
 #else
 #endif
+	{ SYS_compat_30_ntp_gettime, "compat_30" },
 	{ SYS_lfs_bmapv, "lfs" },
 	{ SYS_lfs_markv, "lfs" },
 	{ SYS_lfs_segclean, "lfs" },

Index: src/sys/kern/systrace_args.c
diff -u src/sys/kern/systrace_args.c:1.29.2.5 src/sys/kern/systrace_args.c:1.29.2.6
--- src/sys/kern/systrace_args.c:1.29.2.5	Sun Mar 25 07:19:47 2018
+++ src/sys/kern/systrace_args.c	Tue Mar 27 23:11:18 2018
@@ -1,4 +1,4 @@
-/* $NetBSD: systrace_args.c,v 1.29.2.5 2018/03/25 07:19:47 pgoyette Exp $ */
+/* $NetBSD: systrace_args.c,v 1.29.2.6 2018/03/27 23:11:18 pgoyette Exp $ 

CVS commit: [pgoyette-compat] src/sys/kern

2018-03-27 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Tue Mar 27 23:08:44 UTC 2018

Modified Files:
src/sys/kern [pgoyette-compat]: syscalls.master

Log Message:
Mark syscall #175 modular, since it is provided by the COMPAT_30 code


To generate a diff of this commit:
cvs rdiff -u -r1.291.2.5 -r1.291.2.6 src/sys/kern/syscalls.master

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/syscalls.master
diff -u src/sys/kern/syscalls.master:1.291.2.5 src/sys/kern/syscalls.master:1.291.2.6
--- src/sys/kern/syscalls.master:1.291.2.5	Sun Mar 25 07:19:13 2018
+++ src/sys/kern/syscalls.master	Tue Mar 27 23:08:44 2018
@@ -1,4 +1,4 @@
-	$NetBSD: syscalls.master,v 1.291.2.5 2018/03/25 07:19:13 pgoyette Exp $
+	$NetBSD: syscalls.master,v 1.291.2.6 2018/03/27 23:08:44 pgoyette Exp $
 
 ;	@(#)syscalls.master	8.2 (Berkeley) 1/13/94
 
@@ -381,7 +381,8 @@
 174	STD 	 RUMP	{ ssize_t|sys||pwrite(int fd, const void *buf, \
 			size_t nbyte, int PAD, off_t offset); }
 ; For some reason, ntp_gettime doesn't want to raise SIGSYS when it's excluded.
-175	COMPAT_30	{ int|sys||ntp_gettime(struct ntptimeval30 *ntvp); }
+175	COMPAT_30 MODULAR compat_30	\
+			{ int|sys||ntp_gettime(struct ntptimeval30 *ntvp); }
 #if defined(NTP) || !defined(_KERNEL_OPT)
 176	STD 		{ int|sys||ntp_adjtime(struct timex *tp); }
 #else



CVS import: src/external/bsd/pkg_install/dist

2018-03-27 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Tue Mar 27 23:08:44 UTC 2018

Update of /cvsroot/src/external/bsd/pkg_install/dist
In directory ivanova.netbsd.org:/tmp/cvs-serv4915

Log Message:
Import pkg_install-20180325

Status:

Vendor Tag: PKGSRC
Release Tags:   pkg_install-20180325

U src/external/bsd/pkg_install/dist/add/main.c
C src/external/bsd/pkg_install/dist/add/pkg_add.1
C src/external/bsd/pkg_install/dist/add/perform.c
U src/external/bsd/pkg_install/dist/add/add.h
U src/external/bsd/pkg_install/dist/admin/audit-packages.sh.in
U src/external/bsd/pkg_install/dist/admin/audit-packages.8
U src/external/bsd/pkg_install/dist/admin/download-vulnerability-list.8
C src/external/bsd/pkg_install/dist/admin/main.c
U src/external/bsd/pkg_install/dist/admin/admin.h
C src/external/bsd/pkg_install/dist/admin/audit.c
C src/external/bsd/pkg_install/dist/admin/pkg_admin.1
U src/external/bsd/pkg_install/dist/admin/check.c
U src/external/bsd/pkg_install/dist/admin/download-vulnerability-list.sh.in
U src/external/bsd/pkg_install/dist/x509/pkgsrc.sh
U src/external/bsd/pkg_install/dist/x509/pkgsrc.cnf
U src/external/bsd/pkg_install/dist/x509/signing.txt
C src/external/bsd/pkg_install/dist/lib/version.h
U src/external/bsd/pkg_install/dist/lib/remove.c
U src/external/bsd/pkg_install/dist/lib/automatic.c
U src/external/bsd/pkg_install/dist/lib/version.c
U src/external/bsd/pkg_install/dist/lib/xwrapper.c
U src/external/bsd/pkg_install/dist/lib/pkg_signature.c
U src/external/bsd/pkg_install/dist/lib/pkg_summary.5
C src/external/bsd/pkg_install/dist/lib/vulnerabilities-file.c
U src/external/bsd/pkg_install/dist/lib/pkgsrc.7
U src/external/bsd/pkg_install/dist/lib/str.c
U src/external/bsd/pkg_install/dist/lib/opattern.c
U src/external/bsd/pkg_install/dist/lib/gpgsig.c
U src/external/bsd/pkg_install/dist/lib/defs.h
U src/external/bsd/pkg_install/dist/lib/fexec.c
U src/external/bsd/pkg_install/dist/lib/pkg_io.c
U src/external/bsd/pkg_install/dist/lib/parse-config.c
U src/external/bsd/pkg_install/dist/lib/plist.c
U src/external/bsd/pkg_install/dist/lib/lpkg.c
U src/external/bsd/pkg_install/dist/lib/dewey.c
U src/external/bsd/pkg_install/dist/lib/dewey.h
U src/external/bsd/pkg_install/dist/lib/iterate.c
U src/external/bsd/pkg_install/dist/lib/pkgdb.c
U src/external/bsd/pkg_install/dist/lib/pkcs7.c
U src/external/bsd/pkg_install/dist/lib/var.c
U src/external/bsd/pkg_install/dist/lib/global.c
U src/external/bsd/pkg_install/dist/lib/conflicts.c
C src/external/bsd/pkg_install/dist/lib/license.c
U src/external/bsd/pkg_install/dist/lib/config.h.in
U src/external/bsd/pkg_install/dist/lib/file.c
U src/external/bsd/pkg_install/dist/lib/pkg_install.conf.5.in
C src/external/bsd/pkg_install/dist/lib/lib.h
U src/external/bsd/pkg_install/dist/delete/pkg_delete.1
C src/external/bsd/pkg_install/dist/delete/pkg_delete.c
U src/external/bsd/pkg_install/dist/info/show.c
U src/external/bsd/pkg_install/dist/info/info.h
U src/external/bsd/pkg_install/dist/info/main.c
U src/external/bsd/pkg_install/dist/info/perform.c
U src/external/bsd/pkg_install/dist/info/pkg_info.1
U src/external/bsd/pkg_install/dist/create/pl.c
U src/external/bsd/pkg_install/dist/create/pkg_create.1
U src/external/bsd/pkg_install/dist/create/main.c
U src/external/bsd/pkg_install/dist/create/perform.c
U src/external/bsd/pkg_install/dist/create/create.h
U src/external/bsd/pkg_install/dist/create/util.c
U src/external/bsd/pkg_install/dist/create/build.c

10 conflicts created by this import.
Use the following command to help the merge:

cvs checkout -jPKGSRC:yesterday -jPKGSRC 
src/external/bsd/pkg_install/dist



CVS commit: src/external/bsd/pkg_install/dist/lib

2018-03-27 Thread Sevan Janiyan
Module Name:src
Committed By:   sevan
Date:   Tue Mar 27 22:51:44 UTC 2018

Modified Files:
src/external/bsd/pkg_install/dist/lib: pkg_install.conf.cat.in

Log Message:
Import regenerated catalog file


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.1 -r1.2 \
src/external/bsd/pkg_install/dist/lib/pkg_install.conf.cat.in

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/pkg_install/dist/lib/pkg_install.conf.cat.in
diff -u src/external/bsd/pkg_install/dist/lib/pkg_install.conf.cat.in:1.1.1.1 src/external/bsd/pkg_install/dist/lib/pkg_install.conf.cat.in:1.2
--- src/external/bsd/pkg_install/dist/lib/pkg_install.conf.cat.in:1.1.1.1	Sun Feb  4 08:20:47 2018
+++ src/external/bsd/pkg_install/dist/lib/pkg_install.conf.cat.in	Tue Mar 27 22:51:43 2018
@@ -1,7 +1,7 @@
 PKG_INSTALL.CONF(5)   File Formats Manual  PKG_INSTALL.CONF(5)
 
 NNAAMMEE
- ppkkgg__iinnssttaallll..ccoonnff -- configuration file for package installation tools
+ ppkkgg__iinnssttaallll..ccoonnff - configuration file for package installation tools
 
 DDEESSCCRRIIPPTTIIOONN
  The file ppkkgg__iinnssttaallll..ccoonnff contains system defaults for the package



CVS commit: src/external/bsd/pkg_install/dist

2018-03-27 Thread Sevan Janiyan
Module Name:src
Committed By:   sevan
Date:   Tue Mar 27 22:47:01 UTC 2018

Modified Files:
src/external/bsd/pkg_install/dist/add: pkg_add.cat
src/external/bsd/pkg_install/dist/admin: pkg_admin.cat
src/external/bsd/pkg_install/dist/create: pkg_create.cat
src/external/bsd/pkg_install/dist/delete: pkg_delete.cat
src/external/bsd/pkg_install/dist/info: pkg_info.cat
src/external/bsd/pkg_install/dist/lib: pkg_summary.cat pkgsrc.cat

Log Message:
Import regenerated catalog files


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.1 -r1.2 \
src/external/bsd/pkg_install/dist/add/pkg_add.cat
cvs rdiff -u -r1.2 -r1.3 \
src/external/bsd/pkg_install/dist/admin/pkg_admin.cat
cvs rdiff -u -r1.1.1.1 -r1.2 \
src/external/bsd/pkg_install/dist/create/pkg_create.cat
cvs rdiff -u -r1.1.1.1 -r1.2 \
src/external/bsd/pkg_install/dist/delete/pkg_delete.cat
cvs rdiff -u -r1.1.1.1 -r1.2 \
src/external/bsd/pkg_install/dist/info/pkg_info.cat
cvs rdiff -u -r1.1.1.1 -r1.2 \
src/external/bsd/pkg_install/dist/lib/pkg_summary.cat \
src/external/bsd/pkg_install/dist/lib/pkgsrc.cat

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/pkg_install/dist/add/pkg_add.cat
diff -u src/external/bsd/pkg_install/dist/add/pkg_add.cat:1.1.1.1 src/external/bsd/pkg_install/dist/add/pkg_add.cat:1.2
--- src/external/bsd/pkg_install/dist/add/pkg_add.cat:1.1.1.1	Sun Feb  4 08:20:43 2018
+++ src/external/bsd/pkg_install/dist/add/pkg_add.cat	Tue Mar 27 22:47:00 2018
@@ -1,12 +1,12 @@
 PKG_ADD(1)  General Commands Manual PKG_ADD(1)
 
 NNAAMMEE
- ppkkgg__aadddd -- a utility for installing and upgrading software package
+ ppkkgg__aadddd - a utility for installing and upgrading software package
  distributions
 
 SSYYNNOOPPSSIISS
- ppkkgg__aadddd [--AAffIInnRRUUuuVVvv] [--CC _c_o_n_f_i_g] [--KK _p_k_g___d_b_d_i_r] [--mm _m_a_c_h_i_n_e] [--PP _d_e_s_t_d_i_r]
- [--pp _p_r_e_f_i_x]
+ ppkkgg__aadddd [--AAffhhIInnRRUUuuVVvv] [--CC _c_o_n_f_i_g] [--KK _p_k_g___d_b_d_i_r] [--mm _m_a_c_h_i_n_e]
+ [--PP _d_e_s_t_d_i_r] [--pp _p_r_e_f_i_x]
  _f_i_l_e _._._. [[ftp|http]://[_u_s_e_r][:_p_a_s_s_w_o_r_d]@]_h_o_s_t[:_p_o_r_t][/_p_a_t_h_/]_p_k_g_-_n_a_m_e _._._.
 
 DDEESSCCRRIIPPTTIIOONN
@@ -19,9 +19,9 @@ DDEESSCCRRIIPPTTIIOONN
 
 WWAARRNNIINNGG
  _S_i_n_c_e _t_h_e ppkkgg__aadddd _c_o_m_m_a_n_d _m_a_y _e_x_e_c_u_t_e _s_c_r_i_p_t_s _o_r _p_r_o_g_r_a_m_s _c_o_n_t_a_i_n_e_d
- _w_i_t_h_i_n _a _p_a_c_k_a_g_e _f_i_l_e_, _y_o_u_r _s_y_s_t_e_m _m_a_y _b_e _s_u_s_c_e_p_t_i_b_l_e _t_o _`_`_T_r_o_j_a_n
- _h_o_r_s_e_s_'_' _o_r _o_t_h_e_r _s_u_b_t_l_e _a_t_t_a_c_k_s _f_r_o_m _m_i_s_c_r_e_a_n_t_s _w_h_o _c_r_e_a_t_e _d_a_n_g_e_r_o_u_s
- _p_a_c_k_a_g_e _f_i_l_e_s_.
+ _w_i_t_h_i_n _a _p_a_c_k_a_g_e _f_i_l_e_, _y_o_u_r _s_y_s_t_e_m _m_a_y _b_e _s_u_s_c_e_p_t_i_b_l_e _t_o _"_T_r_o_j_a_n _h_o_r_s_e_s_"
+ _o_r _o_t_h_e_r _s_u_b_t_l_e _a_t_t_a_c_k_s _f_r_o_m _m_i_s_c_r_e_a_n_t_s _w_h_o _c_r_e_a_t_e _d_a_n_g_e_r_o_u_s _p_a_c_k_a_g_e
+ _f_i_l_e_s_.
 
  _Y_o_u _a_r_e _a_d_v_i_s_e_d _t_o _v_e_r_i_f_y _t_h_e _c_o_m_p_e_t_e_n_c_e _a_n_d _i_d_e_n_t_i_t_y _o_f _t_h_o_s_e _w_h_o
  _p_r_o_v_i_d_e _i_n_s_t_a_l_l_a_b_l_e _p_a_c_k_a_g_e _f_i_l_e_s_.  _F_o_r _e_x_t_r_a _p_r_o_t_e_c_t_i_o_n_, _u_s_e _t_h_e _d_i_g_i_t_a_l
@@ -57,6 +57,11 @@ OOPPTTIIOONNSS
  Read the configuration file from _c_o_n_f_i_g instead of the system
  default.
 
+ --DD  Force updating even if the dependencies of depending packages are
+ not satisfied by the new package.  This is used by "make
+ replace", after which one would typically replace the depending
+ packages.
+
  --ff  Force installation to proceed even if prerequisite packages are
  not installed or the install script fails.  Although ppkkgg__aadddd will
  still try to find and auto-install missing prerequisite packages,
@@ -65,10 +70,7 @@ OOPPTTIIOONNSS
  architecture the package was built on differ from that of the
  host.
 
- --DD  Force updating even if the 

CVS commit: src/sys/arch/i386/stand/efiboot

2018-03-27 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Tue Mar 27 14:15:05 UTC 2018

Modified Files:
src/sys/arch/i386/stand/efiboot: Makefile.efiboot boot.c efiboot.c
efiboot.h eficons.c efidelay.c efidisk.c efimemory.c
src/sys/arch/i386/stand/efiboot/bootia32: efibootia32.c
src/sys/arch/i386/stand/efiboot/bootx64: efibootx64.c
Added Files:
src/sys/arch/i386/stand/efiboot: efichar.c

Log Message:
efiboot: Added serial console support.


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/sys/arch/i386/stand/efiboot/Makefile.efiboot
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/i386/stand/efiboot/boot.c
cvs rdiff -u -r1.5 -r1.6 src/sys/arch/i386/stand/efiboot/efiboot.c
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/i386/stand/efiboot/efiboot.h
cvs rdiff -u -r0 -r1.1 src/sys/arch/i386/stand/efiboot/efichar.c
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/i386/stand/efiboot/eficons.c \
src/sys/arch/i386/stand/efiboot/efimemory.c
cvs rdiff -u -r1.1 -r1.2 src/sys/arch/i386/stand/efiboot/efidelay.c
cvs rdiff -u -r1.3 -r1.4 src/sys/arch/i386/stand/efiboot/efidisk.c
cvs rdiff -u -r1.3 -r1.4 \
src/sys/arch/i386/stand/efiboot/bootia32/efibootia32.c
cvs rdiff -u -r1.3 -r1.4 src/sys/arch/i386/stand/efiboot/bootx64/efibootx64.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/i386/stand/efiboot/Makefile.efiboot
diff -u src/sys/arch/i386/stand/efiboot/Makefile.efiboot:1.10 src/sys/arch/i386/stand/efiboot/Makefile.efiboot:1.11
--- src/sys/arch/i386/stand/efiboot/Makefile.efiboot:1.10	Thu Mar  8 10:34:33 2018
+++ src/sys/arch/i386/stand/efiboot/Makefile.efiboot	Tue Mar 27 14:15:05 2018
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile.efiboot,v 1.10 2018/03/08 10:34:33 nonaka Exp $
+# $NetBSD: Makefile.efiboot,v 1.11 2018/03/27 14:15:05 nonaka Exp $
 
 S=		${.CURDIR}/../../../../..
 
@@ -12,7 +12,7 @@ SOURCES?= start.S conf.c devopen.c efibo
 LIBI386SRCS= boot.c biosdisk.c bootinfo.c bootinfo_biosgeom.c
 LIBI386SRCS+= bootmenu.c diskbuf.c exec.c menuutils.c
 LIBI386SRCS+= panic.c parseutils.c pread.c
-LIBI386SRCS+= eficons.c efidelay.c efidev.c efidisk.c efidisk_ll.c
+LIBI386SRCS+= efichar.c eficons.c efidelay.c efidev.c efidisk.c efidisk_ll.c
 LIBI386SRCS+= efigetsecs.c efimemory.c
 SRCS= ${SOURCES} ${EXTRA_SOURCES} ${LIBI386SRCS}
 

Index: src/sys/arch/i386/stand/efiboot/boot.c
diff -u src/sys/arch/i386/stand/efiboot/boot.c:1.7 src/sys/arch/i386/stand/efiboot/boot.c:1.8
--- src/sys/arch/i386/stand/efiboot/boot.c:1.7	Tue Mar 20 10:18:10 2018
+++ src/sys/arch/i386/stand/efiboot/boot.c	Tue Mar 27 14:15:05 2018
@@ -1,4 +1,4 @@
-/*	$NetBSD: boot.c,v 1.7 2018/03/20 10:18:10 nonaka Exp $	*/
+/*	$NetBSD: boot.c,v 1.8 2018/03/27 14:15:05 nonaka Exp $	*/
 
 /*-
  * Copyright (c) 2016 Kimihiro Nonaka 
@@ -463,11 +463,16 @@ command_consdev(char *arg)
 	char *sep, *sep2 = NULL;
 	int ioport, speed = 0;
 
+	if (*arg == '\0') {
+		efi_cons_show();
+		return;
+	}
+
 	sep = strchr(arg, ',');
 	if (sep != NULL) {
 		*sep++ = '\0';
 		sep2 = strchr(sep, ',');
-		if (sep != NULL)
+		if (sep2 != NULL)
 			*sep2++ = '\0';
 	}
 
@@ -555,6 +560,8 @@ void
 command_version(char *arg)
 {
 	CHAR16 *path;
+	char *upath, *ufirmware;
+	int rv;
 
 	if (strcmp(arg, "full") == 0) {
 		printf("ImageBase: 0x%" PRIxPTR "\n",
@@ -562,12 +569,24 @@ command_version(char *arg)
 		printf("Stack: 0x%" PRIxPTR "\n", efi_main_sp);
 		printf("EFI version: %d.%02d\n",
 		ST->Hdr.Revision >> 16, ST->Hdr.Revision & 0x);
-		Print(L"EFI Firmware: %s (rev %d.%02d)\n", ST->FirmwareVendor,
-		ST->FirmwareRevision >> 16, ST->FirmwareRevision & 0x);
+		ufirmware = NULL;
+		rv = ucs2_to_utf8(ST->FirmwareVendor, );
+		if (rv == 0) {
+			printf("EFI Firmware: %s (rev %d.%02d)\n", ufirmware,
+			ST->FirmwareRevision >> 16,
+			ST->FirmwareRevision & 0x);
+			FreePool(ufirmware);
+		}
 		path = DevicePathToStr(efi_bootdp);
-		Print(L"Boot DevicePath: %d:%d:%s\n", DevicePathType(efi_bootdp),
-		DevicePathSubType(efi_bootdp), path);
+		upath = NULL;
+		rv = ucs2_to_utf8(path, );
 		FreePool(path);
+		if (rv == 0) {
+			printf("Boot DevicePath: %d:%d:%s\n",
+			DevicePathType(efi_bootdp),
+			DevicePathSubType(efi_bootdp), upath);
+			FreePool(upath);
+		}
 	}
 
 	printf("\n"
@@ -603,7 +622,9 @@ command_devpath(char *arg)
 	EFI_HANDLE *handles;
 	EFI_DEVICE_PATH *dp0, *dp;
 	CHAR16 *path;
+	char *upath;
 	UINTN cols, rows, row = 0;
+	int rv;
 
 	status = uefi_call_wrapper(ST->ConOut->QueryMode, 4, ST->ConOut,
 	ST->ConOut->Mode->Mode, , );
@@ -626,41 +647,54 @@ command_devpath(char *arg)
 		if (EFI_ERROR(status))
 			break;
 
-		Print(L"DevicePathType %d\n", DevicePathType(dp0));
+		printf("DevicePathType %d\n", DevicePathType(dp0));
 		if (++row >= rows) {
 			row = 0;
-			Print(L"Press Any Key to continue :");
+			printf("Press Any Key to continue :");
 			(void) awaitkey(-1, 0);
-			

CVS commit: src/lib/libm/src

2018-03-27 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Tue Mar 27 11:59:49 UTC 2018

Modified Files:
src/lib/libm/src: s_scalbn.c

Log Message:
Add missing alias for ldexpl on ! __HAVE_LONG_DOUBLE architectures.
Pointed out by Hal Murray on port-arm.


To generate a diff of this commit:
cvs rdiff -u -r1.18 -r1.19 src/lib/libm/src/s_scalbn.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libm/src/s_scalbn.c
diff -u src/lib/libm/src/s_scalbn.c:1.18 src/lib/libm/src/s_scalbn.c:1.19
--- src/lib/libm/src/s_scalbn.c:1.18	Mon May 20 19:40:09 2013
+++ src/lib/libm/src/s_scalbn.c	Tue Mar 27 11:59:49 2018
@@ -12,7 +12,7 @@
 
 #include 
 #if defined(LIBM_SCCS) && !defined(lint)
-__RCSID("$NetBSD: s_scalbn.c,v 1.18 2013/05/20 19:40:09 joerg Exp $");
+__RCSID("$NetBSD: s_scalbn.c,v 1.19 2018/03/27 11:59:49 martin Exp $");
 #endif
 
 /*
@@ -35,6 +35,7 @@ __strong_alias(_scalbnl, _scalbn)
 __strong_alias(_scalblnl, _scalbln)
 __weak_alias(scalbnl, _scalbnl)
 __weak_alias(scalblnl, _scalblnl)
+__weak_alias(ldexpl, _scalblnl)
 #endif
 
 #ifdef __weak_alias



CVS commit: [pgoyette-compat] src

2018-03-27 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Tue Mar 27 07:29:44 UTC 2018

Modified Files:
src/distrib/sets/lists/modules [pgoyette-compat]: mi
src/sys/compat/common [pgoyette-compat]: compat_mod.c compat_mod.h
files.common vfs_syscalls_40.c
src/sys/dev/sysmon [pgoyette-compat]: sysmon_power.c
src/sys/kern [pgoyette-compat]: compat_stub.c
src/sys/modules [pgoyette-compat]: Makefile
src/sys/sys [pgoyette-compat]: compat_stub.h
Added Files:
src/sys/compat/common [pgoyette-compat]: compat_40_mod.c
sysmon_power_40.c
src/sys/modules/compat_40 [pgoyette-compat]: Makefile

Log Message:
Create a compat_40 module


To generate a diff of this commit:
cvs rdiff -u -r1.114.2.6 -r1.114.2.7 src/distrib/sets/lists/modules/mi
cvs rdiff -u -r0 -r1.1.2.1 src/sys/compat/common/compat_40_mod.c \
src/sys/compat/common/sysmon_power_40.c
cvs rdiff -u -r1.24.14.20 -r1.24.14.21 src/sys/compat/common/compat_mod.c
cvs rdiff -u -r1.1.42.8 -r1.1.42.9 src/sys/compat/common/compat_mod.h
cvs rdiff -u -r1.1.2.18 -r1.1.2.19 src/sys/compat/common/files.common
cvs rdiff -u -r1.4 -r1.4.16.1 src/sys/compat/common/vfs_syscalls_40.c
cvs rdiff -u -r1.58 -r1.58.2.1 src/sys/dev/sysmon/sysmon_power.c
cvs rdiff -u -r1.1.2.7 -r1.1.2.8 src/sys/kern/compat_stub.c
cvs rdiff -u -r1.202.2.10 -r1.202.2.11 src/sys/modules/Makefile
cvs rdiff -u -r0 -r1.1.2.1 src/sys/modules/compat_40/Makefile
cvs rdiff -u -r1.1.2.7 -r1.1.2.8 src/sys/sys/compat_stub.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/modules/mi
diff -u src/distrib/sets/lists/modules/mi:1.114.2.6 src/distrib/sets/lists/modules/mi:1.114.2.7
--- src/distrib/sets/lists/modules/mi:1.114.2.6	Sat Mar 24 01:59:15 2018
+++ src/distrib/sets/lists/modules/mi	Tue Mar 27 07:29:43 2018
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.114.2.6 2018/03/24 01:59:15 pgoyette Exp $
+# $NetBSD: mi,v 1.114.2.7 2018/03/27 07:29:43 pgoyette Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 #
@@ -68,6 +68,8 @@
 ./@MODULEDIR@/coda5/coda5.kmod			base-kernel-modules	kmod
 ./@MODULEDIR@/compatbase-kernel-modules	kmod
 ./@MODULEDIR@/compat/compat.kmod		base-kernel-modules	kmod
+./@MODULEDIR@/compat_40base-kernel-modules	kmod
+./@MODULEDIR@/compat_40/compat_40.kmod		base-kernel-modules	kmod
 ./@MODULEDIR@/compat_50base-kernel-modules	kmod
 ./@MODULEDIR@/compat_50/compat_50.kmod		base-kernel-modules	kmod
 ./@MODULEDIR@/compat_60base-kernel-modules	kmod

Index: src/sys/compat/common/compat_mod.c
diff -u src/sys/compat/common/compat_mod.c:1.24.14.20 src/sys/compat/common/compat_mod.c:1.24.14.21
--- src/sys/compat/common/compat_mod.c:1.24.14.20	Sun Mar 25 08:03:26 2018
+++ src/sys/compat/common/compat_mod.c	Tue Mar 27 07:29:43 2018
@@ -1,4 +1,4 @@
-/*	$NetBSD: compat_mod.c,v 1.24.14.20 2018/03/25 08:03:26 pgoyette Exp $	*/
+/*	$NetBSD: compat_mod.c,v 1.24.14.21 2018/03/27 07:29:43 pgoyette Exp $	*/
 
 /*-
  * Copyright (c) 2008 The NetBSD Foundation, Inc.
@@ -34,7 +34,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: compat_mod.c,v 1.24.14.20 2018/03/25 08:03:26 pgoyette Exp $");
+__KERNEL_RCSID(0, "$NetBSD: compat_mod.c,v 1.24.14.21 2018/03/27 07:29:43 pgoyette Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_compat_netbsd.h"
@@ -70,10 +70,6 @@ __KERNEL_RCSID(0, "$NetBSD: compat_mod.c
 static struct sysctllog *compat_clog = NULL;
 #endif
 
-#ifdef COMPAT_40
-#include 
-#endif
-
 #ifdef COMPAT_70
 #include 
 #include 
@@ -189,10 +185,6 @@ static const struct syscall_package comp
 	{ SYS_compat_30_getfh, 0, (sy_call_t *)compat_30_sys_getfh },
 	{ SYS_compat_30_socket, 0, (sy_call_t *)compat_30_sys_socket },
 #endif
-
-#if defined(COMPAT_40)
-	{ SYS_compat_40_mount, 0, (sy_call_t *)compat_40_sys_mount },
-#endif
 	{ 0, 0, NULL },
 };
 
@@ -209,10 +201,10 @@ struct compat_init_fini {
 #ifdef COMPAT_50
 	{ compat_50_init, compat_50_fini },
 #endif
-#if 0	/* NOT YET */
 #ifdef COMPAT_40
 	{ compat_40_init, compat_40_fini },
 #endif
+#if 0	/* NOT YET */
 #ifdef COMPAT_30
 	{ compat_30_init, compat_30_fini },
 #endif
@@ -289,9 +281,6 @@ compat_modcmd(modcmd_t cmd, void *arg)
  * XXX */
 #endif
 #endif /* XXX NOTYET */
-#ifdef COMPAT_40
-		if_40_init();
-#endif
 #ifdef COMPAT_13
 		uvm_13_init();
 #endif
@@ -375,9 +364,6 @@ compat_modcmd(modcmd_t cmd, void *arg)
 		rw_exit(_lock);
 #endif
 #endif	/* COMPAT_16 */
-#ifdef COMPAT_40
-		if_40_fini();
-#endif
 		/*
 		 * Disable included components in reverse order;
 		 * if any component fails to fini(), re-init those

Index: src/sys/compat/common/compat_mod.h
diff -u src/sys/compat/common/compat_mod.h:1.1.42.8 src/sys/compat/common/compat_mod.h:1.1.42.9
--- src/sys/compat/common/compat_mod.h:1.1.42.8	Fri Mar 23 09:38:48 2018
+++ src/sys/compat/common/compat_mod.h	Tue Mar 27 07:29:44 2018
@@ -1,4 +1,4 @@
-/*	$NetBSD: compat_mod.h,v 

CVS commit: src/doc

2018-03-27 Thread Roy Marples
Module Name:src
Committed By:   roy
Date:   Tue Mar 27 06:34:25 UTC 2018

Modified Files:
src/doc: 3RDPARTY CHANGES

Log Message:
Note import of dhcpcd-7.0.2


To generate a diff of this commit:
cvs rdiff -u -r1.1506 -r1.1507 src/doc/3RDPARTY
cvs rdiff -u -r1.2367 -r1.2368 src/doc/CHANGES

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/3RDPARTY
diff -u src/doc/3RDPARTY:1.1506 src/doc/3RDPARTY:1.1507
--- src/doc/3RDPARTY:1.1506	Sat Mar 24 01:52:26 2018
+++ src/doc/3RDPARTY	Tue Mar 27 06:34:25 2018
@@ -1,4 +1,4 @@
-#	$NetBSD: 3RDPARTY,v 1.1506 2018/03/24 01:52:26 kre Exp $
+#	$NetBSD: 3RDPARTY,v 1.1507 2018/03/27 06:34:25 roy Exp $
 #
 # This file contains a list of the software that has been integrated into
 # NetBSD where we are not the primary maintainer.
@@ -334,8 +334,8 @@ Notes:
 Use the dhcp2netbsd script.
 
 Package:	dhcpcd
-Version:	7.0.1
-Current Vers:	7.0.1
+Version:	7.0.2
+Current Vers:	7.0.2
 Maintainer:	roy
 Archive Site:	ftp://roy.marples.name/pub/dhcpcd/
 Home Page:	http://roy.marples.name/projects/dhcpcd/

Index: src/doc/CHANGES
diff -u src/doc/CHANGES:1.2367 src/doc/CHANGES:1.2368
--- src/doc/CHANGES:1.2367	Sat Mar 24 01:52:26 2018
+++ src/doc/CHANGES	Tue Mar 27 06:34:25 2018
@@ -1,4 +1,4 @@
-# LIST OF CHANGES FROM LAST RELEASE:			<$Revision: 1.2367 $>
+# LIST OF CHANGES FROM LAST RELEASE:			<$Revision: 1.2368 $>
 #
 #
 # [Note: This file does not mention every change made to the NetBSD source tree.
@@ -130,3 +130,4 @@ Changes from NetBSD 8.0 to NetBSD 9.0:
 	macppc: Enable Bluetooth support by default in GENERIC kernel.
 		[sevan 20180316]
 	tzdata updated to 2017d [kre 20180324]
+	dhcpcd: Import 7.0.2. [roy 20180327]



CVS commit: src/external/bsd/dhcpcd/include

2018-03-27 Thread Roy Marples
Module Name:src
Committed By:   roy
Date:   Tue Mar 27 06:18:40 UTC 2018

Modified Files:
src/external/bsd/dhcpcd/include: config.h

Log Message:
Add support for setproctitle(3)


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/external/bsd/dhcpcd/include/config.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/dhcpcd/include/config.h
diff -u src/external/bsd/dhcpcd/include/config.h:1.2 src/external/bsd/dhcpcd/include/config.h:1.3
--- src/external/bsd/dhcpcd/include/config.h:1.2	Sat Oct  7 14:11:07 2017
+++ src/external/bsd/dhcpcd/include/config.h	Tue Mar 27 06:18:40 2018
@@ -9,6 +9,7 @@
 #define HAVE_IFAM_ADDRFLAGS
 #define HAVE_IFADDRS_ADDRFLAGS
 #define HAVE_UTIL_H
+#define HAVE_SETPROCTITLE
 #define HAVE_SYS_QUEUE_H
 #define HAVE_REALLOCARRAY
 #define HAVE_KQUEUE



CVS commit: src/external/bsd/dhcpcd/dist/src

2018-03-27 Thread Roy Marples
Module Name:src
Committed By:   roy
Date:   Tue Mar 27 06:16:34 UTC 2018

Modified Files:
src/external/bsd/dhcpcd/dist/src: dhcp.c dhcpcd.c

Log Message:
Sync


To generate a diff of this commit:
cvs rdiff -u -r1.8 -r1.9 src/external/bsd/dhcpcd/dist/src/dhcp.c \
src/external/bsd/dhcpcd/dist/src/dhcpcd.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/dhcpcd/dist/src/dhcp.c
diff -u src/external/bsd/dhcpcd/dist/src/dhcp.c:1.8 src/external/bsd/dhcpcd/dist/src/dhcp.c:1.9
--- src/external/bsd/dhcpcd/dist/src/dhcp.c:1.8	Mon Jan 29 11:13:06 2018
+++ src/external/bsd/dhcpcd/dist/src/dhcp.c	Tue Mar 27 06:16:34 2018
@@ -3653,6 +3653,7 @@ dhcp_start1(void *arg)
 
 	state = D_STATE(ifp);
 	clock_gettime(CLOCK_MONOTONIC, >started);
+	state->interval = 0;
 	free(state->offer);
 	state->offer = NULL;
 	state->offer_len = 0;
@@ -3891,7 +3892,7 @@ dhcp_abort(struct interface *ifp)
 }
 
 void
-dhcp_handleifa(int cmd, struct ipv4_addr *ia)
+dhcp_handleifa(int cmd, struct ipv4_addr *ia, pid_t pid)
 {
 	struct interface *ifp;
 	struct dhcp_state *state;
@@ -3905,12 +3906,13 @@ dhcp_handleifa(int cmd, struct ipv4_addr
 
 	if (cmd == RTM_DELADDR) {
 		if (state->addr == ia) {
-			loginfox("%s: deleted IP address %s",
-			ifp->name, ia->saddr);
+			loginfox("%s: pid %d deleted IP address %s",
+			ifp->name, pid, ia->saddr);
 			state->addr = NULL;
 			/* Don't clear the added state as we need
 			 * to drop the lease. */
 			dhcp_drop(ifp, "EXPIRE");
+			dhcp_start1(ifp);
 		}
 		return;
 	}
Index: src/external/bsd/dhcpcd/dist/src/dhcpcd.c
diff -u src/external/bsd/dhcpcd/dist/src/dhcpcd.c:1.8 src/external/bsd/dhcpcd/dist/src/dhcpcd.c:1.9
--- src/external/bsd/dhcpcd/dist/src/dhcpcd.c:1.8	Mon Jan 29 11:13:06 2018
+++ src/external/bsd/dhcpcd/dist/src/dhcpcd.c	Tue Mar 27 06:16:34 2018
@@ -437,19 +437,15 @@ configure_interface1(struct interface *i
 		ifo->options &=
 		~(DHCPCD_IPV6RS | DHCPCD_DHCP6 | DHCPCD_WAITIP6);
 
 	/* We want to disable kernel interface RA as early as possible. */
 	if (ifp->active == IF_ACTIVE_USER &&
-	!(ifp->ctx->options & DHCPCD_DUMPLEASE))
+	ifo->options & DHCPCD_IPV6 &&
+	!(ifp->ctx->options & (DHCPCD_DUMPLEASE | DHCPCD_TEST)))
 	{
-		int ra_global, ra_iface;
-
 		/* If not doing any DHCP, disable the RDNSS requirement. */
 		if (!(ifo->options & (DHCPCD_DHCP | DHCPCD_DHCP6)))
 			ifo->options &= ~DHCPCD_IPV6RA_REQRDNSS;
-		ra_global = if_checkipv6(ifp->ctx, NULL);
-		ra_iface = if_checkipv6(ifp->ctx, ifp);
-		if (ra_global == -1 || ra_iface == -1)
-			ifo->options &= ~DHCPCD_IPV6RS;
+		if_setup_inet6(ifp);
 	}
 #endif
 
@@ -959,20 +955,6 @@ dhcpcd_activateinterface(struct interfac
 	}
 }
 
-static void
-dhcpcd_handlelink(void *arg)
-{
-	struct dhcpcd_ctx *ctx;
-
-	ctx = arg;
-	if (if_handlelink(ctx) == -1) {
-		logerr(__func__);
-		eloop_event_delete(ctx->eloop, ctx->link_fd);
-		close(ctx->link_fd);
-		ctx->link_fd = -1;
-	}
-}
-
 int
 dhcpcd_handleinterface(void *arg, int action, const char *ifname)
 {
@@ -1045,6 +1027,83 @@ dhcpcd_handleinterface(void *arg, int ac
 	return 1;
 }
 
+static void
+dhcpcd_handlelink(void *arg)
+{
+	struct dhcpcd_ctx *ctx = arg;
+
+	if (if_handlelink(ctx) == -1) {
+		if (errno == ENOBUFS || errno == ENOMEM) {
+			dhcpcd_linkoverflow(ctx);
+			return;
+		}
+		logerr(__func__);
+	}
+}
+
+static void
+dhcpcd_checkcarrier(void *arg)
+{
+	struct interface *ifp = arg;
+
+	dhcpcd_handlecarrier(ifp->ctx, LINK_UNKNOWN, ifp->flags, ifp->name);
+}
+
+void
+dhcpcd_linkoverflow(struct dhcpcd_ctx *ctx)
+{
+	struct if_head *ifaces;
+	struct ifaddrs *ifaddrs;
+	struct interface *ifp, *ifn, *ifp1;
+
+	logerrx("route socket overflowed - learning interface state");
+
+	/* Close the existing socket and open a new one.
+	 * This is easier than draining the kernel buffer of an
+	 * in-determinate size. */
+	eloop_event_delete(ctx->eloop, ctx->link_fd);
+	close(ctx->link_fd);
+	if_closesockets_os(ctx);
+	if (if_opensockets_os(ctx) == -1) {
+		logerr("%s: if_opensockets", __func__);
+		eloop_exit(ctx->eloop, EXIT_FAILURE);
+		return;
+	}
+	eloop_event_add(ctx->eloop, ctx->link_fd, dhcpcd_handlelink, ctx);
+
+	/* Work out the current interfaces. */
+	ifaces = if_discover(ctx, , ctx->ifc, ctx->ifv);
+
+	/* Punt departed interfaces */
+	TAILQ_FOREACH_SAFE(ifp, ctx->ifaces, next, ifn) {
+		if (if_find(ifaces, ifp->name) != NULL)
+			continue;
+		dhcpcd_handleinterface(ctx, -1, ifp->name);
+	}
+
+	/* Add new interfaces */
+	TAILQ_FOREACH_SAFE(ifp, ifaces, next, ifn) {
+		ifp1 = if_find(ctx->ifaces, ifp->name);
+		if (ifp1 != NULL) {
+			/* If the interface already exists,
+			 * check carrier state. */
+			eloop_timeout_add_sec(ctx->eloop, 0,
+			dhcpcd_checkcarrier, ifp1);
+			continue;
+		}
+		TAILQ_REMOVE(ifaces, ifp, next);
+		TAILQ_INSERT_TAIL(ctx->ifaces, ifp, next);
+		
@@ -437,19 +437,15 @@ configure_interface1(struct interface *i
 		~(DHCPCD_IPV6RS | DHCPCD_DHCP6 | DHCPCD_WAITIP6);
 
-	/* We want to disable kernel interface RA as early as possible. */
+	/* We want to setup INET6 on the interface as soon as possible. */
 	if (ifp->active == IF_ACTIVE_USER &&

CVS import: src/external/bsd/dhcpcd/dist

2018-03-27 Thread Roy Marples
Module Name:src
Committed By:   roy
Date:   Tue Mar 27 06:14:40 UTC 2018

Update of /cvsroot/src/external/bsd/dhcpcd/dist
In directory ivanova.netbsd.org:/tmp/cvs-serv3763

Log Message:
Import dhcpcd-7.0.2 with the following changes:

  *  Added support for setproctitle(3)
  *  Kernel RA is no longer disabled when IPv6 is disabled in dhcpcd
  *  DHCPv6 PD is no longer stopped if no Routers are found
  *  If the DHCP leased address is deleted, enter the reboot state
  *  DHCPv6 unicast is no longer performed when not in master mode
  *  dhcpcd will now detect netlink/route socket overflows ad re-sync

Status:

Vendor Tag: roy
Release Tags:   dhcpcd-7-0-2

U src/external/bsd/dhcpcd/dist/.arcconfig
U src/external/bsd/dhcpcd/dist/.gitignore
U src/external/bsd/dhcpcd/dist/BUILDING.md
U src/external/bsd/dhcpcd/dist/LICENSE
U src/external/bsd/dhcpcd/dist/Makefile
U src/external/bsd/dhcpcd/dist/Makefile.inc
U src/external/bsd/dhcpcd/dist/README.md
U src/external/bsd/dhcpcd/dist/config-null.mk
U src/external/bsd/dhcpcd/dist/configure
U src/external/bsd/dhcpcd/dist/iconfig.mk
U src/external/bsd/dhcpcd/dist/compat/_strtoi.h
U src/external/bsd/dhcpcd/dist/compat/arc4random.c
U src/external/bsd/dhcpcd/dist/compat/arc4random.h
U src/external/bsd/dhcpcd/dist/compat/bitops.h
U src/external/bsd/dhcpcd/dist/compat/queue.h
U src/external/bsd/dhcpcd/dist/compat/arc4random_uniform.c
U src/external/bsd/dhcpcd/dist/compat/arc4random_uniform.h
U src/external/bsd/dhcpcd/dist/compat/reallocarray.c
U src/external/bsd/dhcpcd/dist/compat/dprintf.c
U src/external/bsd/dhcpcd/dist/compat/dprintf.h
U src/external/bsd/dhcpcd/dist/compat/endian.h
U src/external/bsd/dhcpcd/dist/compat/pidfile.c
U src/external/bsd/dhcpcd/dist/compat/pidfile.h
U src/external/bsd/dhcpcd/dist/compat/reallocarray.h
U src/external/bsd/dhcpcd/dist/compat/strlcpy.c
U src/external/bsd/dhcpcd/dist/compat/strlcpy.h
U src/external/bsd/dhcpcd/dist/compat/strtoi.c
U src/external/bsd/dhcpcd/dist/compat/strtoi.h
U src/external/bsd/dhcpcd/dist/compat/strtou.c
U src/external/bsd/dhcpcd/dist/compat/crypt/hmac.c
U src/external/bsd/dhcpcd/dist/compat/crypt/hmac.h
U src/external/bsd/dhcpcd/dist/compat/crypt/md5.c
U src/external/bsd/dhcpcd/dist/compat/crypt/md5.h
U src/external/bsd/dhcpcd/dist/compat/crypt/sha256.c
U src/external/bsd/dhcpcd/dist/compat/crypt/sha256.h
C src/external/bsd/dhcpcd/dist/src/dhcp.c
U src/external/bsd/dhcpcd/dist/src/GNUmakefile
U src/external/bsd/dhcpcd/dist/src/Makefile
U src/external/bsd/dhcpcd/dist/src/arp.c
U src/external/bsd/dhcpcd/dist/src/arp.h
U src/external/bsd/dhcpcd/dist/src/auth.c
U src/external/bsd/dhcpcd/dist/src/auth.h
U src/external/bsd/dhcpcd/dist/src/bpf.c
U src/external/bsd/dhcpcd/dist/src/bpf.h
U src/external/bsd/dhcpcd/dist/src/common.c
U src/external/bsd/dhcpcd/dist/src/common.h
U src/external/bsd/dhcpcd/dist/src/control.c
U src/external/bsd/dhcpcd/dist/src/control.h
U src/external/bsd/dhcpcd/dist/src/defs.h
U src/external/bsd/dhcpcd/dist/src/dev.c
U src/external/bsd/dhcpcd/dist/src/dev.h
U src/external/bsd/dhcpcd/dist/src/dhcp-common.c
U src/external/bsd/dhcpcd/dist/src/dhcp-common.h
U src/external/bsd/dhcpcd/dist/src/dhcp.h
U src/external/bsd/dhcpcd/dist/src/dhcp6.c
U src/external/bsd/dhcpcd/dist/src/dhcp6.h
U src/external/bsd/dhcpcd/dist/src/dhcpcd.conf.5.in
U src/external/bsd/dhcpcd/dist/src/dhcpcd.8.in
U src/external/bsd/dhcpcd/dist/src/dhcpcd-definitions-small.conf
U src/external/bsd/dhcpcd/dist/src/dhcpcd-definitions.conf
U src/external/bsd/dhcpcd/dist/src/dhcpcd-embedded.c.in
U src/external/bsd/dhcpcd/dist/src/dhcpcd-embedded.h.in
C src/external/bsd/dhcpcd/dist/src/dhcpcd.c
U src/external/bsd/dhcpcd/dist/src/dhcpcd.conf
U src/external/bsd/dhcpcd/dist/src/genembedc
U src/external/bsd/dhcpcd/dist/src/dhcpcd.h
U src/external/bsd/dhcpcd/dist/src/duid.c
U src/external/bsd/dhcpcd/dist/src/duid.h
U src/external/bsd/dhcpcd/dist/src/eloop.c
U src/external/bsd/dhcpcd/dist/src/eloop.h
U src/external/bsd/dhcpcd/dist/src/if-linux-wext.c
U src/external/bsd/dhcpcd/dist/src/genembedh
U src/external/bsd/dhcpcd/dist/src/if-bsd.c
U src/external/bsd/dhcpcd/dist/src/if-linux.c
U src/external/bsd/dhcpcd/dist/src/if-options.c
U src/external/bsd/dhcpcd/dist/src/if-options.h
U src/external/bsd/dhcpcd/dist/src/if-sun.c
U src/external/bsd/dhcpcd/dist/src/if.c
U src/external/bsd/dhcpcd/dist/src/if.h
U src/external/bsd/dhcpcd/dist/src/ipv4.c
U src/external/bsd/dhcpcd/dist/src/ipv4.h
U src/external/bsd/dhcpcd/dist/src/ipv4ll.c
U src/external/bsd/dhcpcd/dist/src/ipv4ll.h
U src/external/bsd/dhcpcd/dist/src/ipv6.c
U src/external/bsd/dhcpcd/dist/src/ipv6.h
U src/external/bsd/dhcpcd/dist/src/ipv6nd.c
U src/external/bsd/dhcpcd/dist/src/ipv6nd.h
U src/external/bsd/dhcpcd/dist/src/logerr.c
U src/external/bsd/dhcpcd/dist/src/logerr.h
U src/external/bsd/dhcpcd/dist/src/route.c
U src/external/bsd/dhcpcd/dist/src/route.h
U src/external/bsd/dhcpcd/dist/src/sa.c
U src/external/bsd/dhcpcd/dist/src/sa.h
U